import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */


/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'/'el-icon-x' the icon show in the sidebar
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [
  {
    path: '/login',
    component: () => import('@/views/login/index'),
    hidden: true
  },

  {
    path: '/404',
    component: () => import('@/views/404'),
    hidden: true
  },

  // {
  //   path: '/',
  //   component: Layout,
  //   redirect: '/dashboard',
  //   children: [{
  //     path: 'dashboard',
  //     name: 'Dashboard',
  //     component: () => import('@/views/dashboard/index'),
  //     meta: { title: '首页' }
  //   }]
  // },
  {
    path: '/',
    component: () => import('@/views/dashboard/index'),
      meta: { title: '首页' },
    // redirect: '/dashboard',
  },

  {
    path: '/log',
    component: () => import('@/views/log/index'),
    meta: { title: '相关数据' }
  },

/****录入 */
  {
    path: '/waipandan',
    name: 'waipandan',
    component: () => import('@/views/luru/waipandan'),
    meta: { title: '外判单'}
  },
  {
    path: '/gongzi',
    name: 'gongzi',
    component: () => import('@/views/luru/gongzi'),
    meta: { title: '工资管理' }
  },
  {
    path: '/gongshi',
    name: 'gongshi',
    component: () => import('@/views/luru/gongshi'),
    meta: { title: '工时管理'}
  },

/****处理数据 */
{
  path: '/current',
  name: 'current',
  component: () => import('@/views/handle/current'),
  meta: { title: '当月'}
},
{
  path: '/history',
  name: 'history',
  component: () => import('@/views/handle/history'),
  meta: { title: '历史' }
},
{
  path: '/merge',
  name: 'merge',
  component: () => import('@/views/handle/merge'),
  meta: { title: '合并'}
},


/****统计数据 */

{
  path: '/yingyun',
  name: 'yingyun',
  component: () => import('@/views/tongji/yingyun'),
  meta: { title: '营运数据' }
},
{
  path: '/gerengongshi',
  name: 'gerengongshi',
  component: () => import('@/views/tongji/gerengongshi'),
  meta: { title: '个人工时'}
},
{
  path: '/fenpeizongbiao',
  name: 'fenpeizongbiao',
  component: () => import('@/views/tongji/fenpeizongbiao'),
  meta: { title: '分配总表'}
},
{
  path: '/yuangonggongzi',
  name: 'yuangonggongzi',
  component: () => import('@/views/tongji/yuangonggongzi'),
  meta: { title: '员工工资'}
},

// {
//     path: '/luru',
//     redirect: '/luru/waipandan',
//     name: 'luru',
//     component: Layout,
//     meta: { title: '录入数据' },
//     children: [
//       {
//         path: 'waipandan',
//         name: 'waipandan',
//         component: () => import('@/views/luru/waipandan'),
//         meta: { title: '外判单', icon: 'form' }
//       },
//       {
//         path: 'gongzi',
//         name: 'gongzi',
//         component: () => import('@/views/luru/gongzi'),
//         meta: { title: '工资管理', icon: 'form' }
//       }
//     ]
//   },

  


  // 二级菜单栏
  // {
  //   path: '/example',
  //   component: Layout,
  //   redirect: '/example/table',
  //   name: 'Example',
  //   meta: { title: 'Example', icon: 'el-icon-s-help' },
  //   children: [
  //     {
  //       path: 'table',
  //       name: 'Table',
  //       component: () => import('@/views/table/index'),
  //       meta: { title: 'Table', icon: 'table' }
  //     },
  //     {
  //       path: 'tree',
  //       name: 'Tree',
  //       component: () => import('@/views/tree/index'),
  //       meta: { title: 'Tree', icon: 'tree' }
  //     }
  //   ]
  // },

 

  // 三级菜单栏
  // {
  //   path: '/nested',
  //   component: Layout,
  //   redirect: '/nested/menu1',
  //   name: 'Nested',
  //   meta: {
  //     title: 'Nested',
  //     icon: 'nested'
  //   },
  //   children: [
  //     {
  //       path: 'menu1',
  //       component: () => import('@/views/nested/menu1/index'), // Parent router-view
  //       name: 'Menu1',
  //       meta: { title: 'Menu1' },
  //       children: [
  //         {
  //           path: 'menu1-1',
  //           component: () => import('@/views/nested/menu1/menu1-1'),
  //           name: 'Menu1-1',
  //           meta: { title: 'Menu1-1' }
  //         },
  //         {
  //           path: 'menu1-2',
  //           component: () => import('@/views/nested/menu1/menu1-2'),
  //           name: 'Menu1-2',
  //           meta: { title: 'Menu1-2' },
  //           children: [
  //             {
  //               path: 'menu1-2-1',
  //               component: () => import('@/views/nested/menu1/menu1-2/menu1-2-1'),
  //               name: 'Menu1-2-1',
  //               meta: { title: 'Menu1-2-1' }
  //             },
  //             {
  //               path: 'menu1-2-2',
  //               component: () => import('@/views/nested/menu1/menu1-2/menu1-2-2'),
  //               name: 'Menu1-2-2',
  //               meta: { title: 'Menu1-2-2' }
  //             }
  //           ]
  //         },
  //         {
  //           path: 'menu1-3',
  //           component: () => import('@/views/nested/menu1/menu1-3'),
  //           name: 'Menu1-3',
  //           meta: { title: 'Menu1-3' }
  //         }
  //       ]
  //     },
  //     {
  //       path: 'menu2',
  //       component: () => import('@/views/nested/menu2/index'),
  //       name: 'Menu2',
  //       meta: { title: 'menu2' }
  //     }
  //   ]
  // },

  // 跳转到外部链接
  // {
  //   path: 'external-link',
  //   component: Layout,
  //   children: [
  //     {
  //       path: 'https://panjiachen.github.io/vue-element-admin-site/#/',
  //       meta: { title: 'External Link', icon: 'link' }
  //     }
  //   ]
  // },

  // 404 page must be placed at the end !!!
  { path: '*', redirect: '/404', hidden: true }
]

const createRouter = () => new Router({
  // mode: 'history', // require service support
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
})

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router
